@@ -201,6 +201,7 @@ test_that("number_timeseries works", {
     def = "n", thresh = "tri", frames_per_set = 20,
     detrend = TRUE
   )
+  skip_on_cran()
   ans0 <- paste0(
     "50",
     c(
@@ -225,16 +226,6 @@ test_that("number_timeseries works", {
     c("auto=0", "auto=5029"),
     c("auto=5363", "auto=0")
   ) # rhub ubuntu
-  ans5 <- stringr::str_replace(
-    ans0,
-    c("auto=0", "auto=5029"),
-    c("auto=574", "auto=0")
-  ) # CRAN solaris
-  ans6 <- stringr::str_replace(
-    ans0,
-    c("auto=0", "auto=5029"),
-    c("auto=5214", "auto=0")
-  ) # CRAN Windows oldrel
   lfnts <- list.files("number_timeseries")
   if (all(lfnts %in% ans0)) {
     expect_true(all(lfnts %in% ans0))
